@@ -27,7 +27,7 @@ func init() {
 
 // OverlayCmd is the 'overlay' command that allows to manage writable overlay.
 var OverlayCmd = &cobra.Command{
-	RunE: func(cmd *cobra.Command, args []string) error {
+	RunE: func(_ *cobra.Command, _ []string) error {
 		return errors.New("invalid command")
 	},
 	DisableFlagsInUseLine: true,
