@@ -342,7 +342,7 @@ func (c ctx) apptainerEnvFile(t *testing.T) {
 	tests := []struct {
 		name     string
 		image    string
-		envFile  string
+		envFiles []string
 		envOpt   []string
 		hostEnv  []string
 		matchEnv string
@@ -351,7 +351,7 @@ func (c ctx) apptainerEnvFile(t *testing.T) {
 		{
 			name:     "DefaultPathOverride",
 			image:    c.env.ImagePath,
-			envFile:  "PATH=/",
+			envFiles: []string{"PATH=/"},
 			matchEnv: "PATH",
 			matchVal: "/",
 		},
@@ -359,43 +359,50 @@ func (c ctx) apptainerEnvFile(t *testing.T) {
 			name:     "DefaultPathOverrideEnvOptionPrecedence",
 			image:    c.env.ImagePath,
 			envOpt:   []string{"PATH=/etc"},
-			envFile:  "PATH=/",
+			envFiles: []string{"PATH=/"},
 			matchEnv: "PATH",
 			matchVal: "/etc",
 		},
 		{
-			name:     "DefaultPathOverrideEnvOptionPrecedence",
+			name:     "DefaultPathOverrideEnvFileOptionPrecedence",
+			image:    c.env.ImagePath,
+			envFiles: []string{"PATH=/", "PATH=/etc"},
+			matchEnv: "PATH",
+			matchVal: "/etc",
+		},
+		{
+			name:     "DefaultPathOverrideEnvAndEnvFileOptionPrecedence",
 			image:    c.env.ImagePath,
 			envOpt:   []string{"PATH=/etc"},
-			envFile:  "PATH=/",
+			envFiles: []string{"PATH=/", "PATH=/foo"},
 			matchEnv: "PATH",
 			matchVal: "/etc",
 		},
 		{
 			name:     "AppendDefaultPath",
 			image:    c.env.ImagePath,
-			envFile:  "APPEND_PATH=/",
+			envFiles: []string{"APPEND_PATH=/"},
 			matchEnv: "PATH",
 			matchVal: imageDefaultPath + ":/",
 		},
 		{
 			name:     "AppendLiteralDefaultPath",
 			image:    c.env.ImagePath,
-			envFile:  `PATH="\$PATH:/"`,
+			envFiles: []string{`PATH="\$PATH:/"`},
 			matchEnv: "PATH",
 			matchVal: imageDefaultPath + ":/",
 		},
 		{
 			name:     "PrependLiteralDefaultPath",
 			image:    c.env.ImagePath,
-			envFile:  `PATH="/:\$PATH"`,
+			envFiles: []string{`PATH="/:\$PATH"`},
 			matchEnv: "PATH",
 			matchVal: "/:" + imageDefaultPath,
 		},
 		{
 			name:     "PrependDefaultPath",
 			image:    c.env.ImagePath,
-			envFile:  "PREPEND_PATH=/",
+			envFiles: []string{"PREPEND_PATH=/"},
 			matchEnv: "PATH",
 			matchVal: "/:" + imageDefaultPath,
 		},
@@ -408,14 +415,14 @@ func (c ctx) apptainerEnvFile(t *testing.T) {
 		{
 			name:     "CustomLdLibraryPath",
 			image:    c.env.ImagePath,
-			envFile:  "LD_LIBRARY_PATH=/foo",
+			envFiles: []string{"LD_LIBRARY_PATH=/foo"},
 			matchEnv: "LD_LIBRARY_PATH",
 			matchVal: "/foo:" + apptainerLibs,
 		},
 		{
 			name:     "CustomTrailingCommaPath",
 			image:    c.env.ImagePath,
-			envFile:  "LD_LIBRARY_PATH=/foo,",
+			envFiles: []string{"LD_LIBRARY_PATH=/foo,"},
 			matchEnv: "LD_LIBRARY_PATH",
 			matchVal: "/foo,:" + apptainerLibs,
 		},
@@ -426,9 +433,12 @@ func (c ctx) apptainerEnvFile(t *testing.T) {
 		if tt.envOpt != nil {
 			args = append(args, "--env", strings.Join(tt.envOpt, ","))
 		}
-		if tt.envFile != "" {
-			os.WriteFile(p, []byte(tt.envFile), 0o644)
-			args = append(args, "--env-file", p)
+		if len(tt.envFiles) > 0 {
+			for i, envFile := range tt.envFiles {
+				filename := fmt.Sprint(p, i)
+				os.WriteFile(filename, []byte(envFile), 0o644)
+				args = append(args, "--env-file", filename)
+			}
 		}
 		args = append(args, tt.image, "/bin/sh", "-c", "echo $"+tt.matchEnv)
 
