@@ -22,6 +22,7 @@ import (
 	"gopkg.in/yaml.v3"
 )
 
+// #nosec G101
 const testToken = "eyJhbGciOiJSUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwibmFtZSI6IkpvaG4gRG9lIiwiYWRtaW4iOnRydWUsImlhdCI6MTUxNjIzOTAyMn0.TCYt5XsITJX1CxPCT8yAV-TVkIEq_PbChOMqsLfRoPsnsgw5WEuts01mq-pQy7UJiN5mgRxD-WUcX16dUEMGlv50aqzpqh4Qktb3rk-BuQy72IFLOqV0G_zS245-kronKb78cPN25DGlcTwLtjPAYuNzVBAh4vGHSrQyHUdBBPM"
 
 // NOTE: VerifyToken() cannot be fully tested unless we have a dummy token for the token service to authenticate, so we basically only test a few error cases.
@@ -92,13 +93,13 @@ func TestWriteToReadFrom(t *testing.T) {
 
 			test.c.WriteTo(&r)
 
-			item, err := ReadFrom(&r)
+			newConfig, err := ReadFrom(&r)
 			if err != nil {
 				t.Errorf("unexpected failure running %s test: %s", test.name, err)
 			}
 
-			if !reflect.DeepEqual(test.c, *item) {
-				t.Errorf("failed to read/write config:\n\thave: %v\n\twant: %v", test.c, *item)
+			if !reflect.DeepEqual(test.c, *newConfig) {
+				t.Errorf("failed to read/write config:\n\thave: %v\n\twant: %v", test.c, *newConfig)
 			}
 		})
 	}
@@ -337,7 +338,7 @@ func TestSyncFrom(t *testing.T) {
 
 	for _, test := range testsPass {
 		t.Run(test.name, func(t *testing.T) {
-			if err := test.usr.SyncFrom(&test.sys); err != nil {
+			if err := test.usr.SyncFrom(&test.sys); err != nil { //nolint:gosec
 				t.Error("failed to sync from sys")
 			}
 
