@@ -44,7 +44,7 @@ func ApplyBuildConfig(config *File) {
 // SetBinaryPath sets the value of the binary path, substituting the
 // user's $PATH plus ":" for "$PATH:" in BinaryPath.  If nonSuid is true,
 // then SuidBinaryPath gets the same value as BinaryPath, otherwise
-// SuidBinaryPath gets the value of the binary path with with "$PATH:"
+// SuidBinaryPath gets the value of the binary path with "$PATH:"
 // replaced with nothing.  libexecdir + "apptainer/bin" is always included
 // either at the beginning of $PATH if present, or the very beginning.
 func SetBinaryPath(libexecDir string, nonSuid bool) {
@@ -77,7 +77,10 @@ func SetBinaryPath(libexecDir string, nonSuid bool) {
 // File describes the apptainer.conf file options
 type File struct {
 	AllowSetuid               bool     `default:"yes" authorized:"yes,no" directive:"allow setuid"`
+	AllowIpcNs                bool     `default:"yes" authorized:"yes,no" directive:"allow ipc ns"`
 	AllowPidNs                bool     `default:"yes" authorized:"yes,no" directive:"allow pid ns"`
+	AllowUserNs               bool     `default:"yes" authorized:"yes,no" directive:"allow user ns"`
+	AllowUtsNs                bool     `default:"yes" authorized:"yes,no" directive:"allow uts ns"`
 	ConfigPasswd              bool     `default:"yes" authorized:"yes,no" directive:"config passwd"`
 	ConfigGroup               bool     `default:"yes" authorized:"yes,no" directive:"config group"`
 	ConfigResolvConf          bool     `default:"yes" authorized:"yes,no" directive:"config resolv_conf"`
@@ -114,6 +117,7 @@ type File struct {
 	AllowNetUsers             []string `directive:"allow net users"`
 	AllowNetGroups            []string `directive:"allow net groups"`
 	AllowNetNetworks          []string `directive:"allow net networks"`
+	AllowNetnsPaths           []string `directive:"allow netns paths"`
 	RootDefaultCapabilities   string   `default:"full" authorized:"full,file,no" directive:"root default capabilities"`
 	MemoryFSType              string   `default:"tmpfs" authorized:"tmpfs,ramfs" directive:"memory fs type"`
 	CniConfPath               string   `directive:"cni configuration path"`
@@ -169,6 +173,11 @@ allow setuid = {{ if eq .AllowSetuid true }}yes{{ else }}no{{ end }}
 # to utilize.
 max loop devices = {{ .MaxLoopDevices }}
 
+# ALLOW IPC NS: [BOOL]
+# DEFAULT: yes
+# Should we allow users to request the IPC namespace?
+allow ipc ns = {{ if eq .AllowIpcNs true }}yes{{ else }}no{{ end }}
+
 # ALLOW PID NS: [BOOL]
 # DEFAULT: yes
 # Should we allow users to request the PID namespace? Note that for some HPC
@@ -177,6 +186,16 @@ max loop devices = {{ .MaxLoopDevices }}
 # systems, the PID namespace is always used)
 allow pid ns = {{ if eq .AllowPidNs true }}yes{{ else }}no{{ end }}
 
+# ALLOW USER NS: [BOOL]
+# DEFAULT: yes
+# Should we allow users to request the USER namespace?
+allow user ns = {{ if eq .AllowUserNs true }}yes{{ else }}no{{ end }}
+
+# ALLOW UTS NS: [BOOL]
+# DEFAULT: yes
+# Should we allow users to request the UTS namespace?
+allow uts ns = {{ if eq .AllowUtsNs true }}yes{{ else }}no{{ end }}
+
 # CONFIG PASSWD: [BOOL]
 # DEFAULT: yes
 # If /etc/passwd exists within the container, this will automatically append
@@ -437,11 +456,13 @@ allow container dir = {{ if eq .AllowContainerDir true }}yes{{ else }}no{{ end }
 
 # ALLOW NET USERS: [STRING]
 # DEFAULT: NULL
-# Allow specified root administered CNI network configurations to be used by the
-# specified list of users. By default only root may use CNI configuration,
-# except in the case of a fakeroot execution where only 40_fakeroot.conflist
-# is used. This feature only applies when Apptainer is running in
-# SUID mode and the user is non-root.
+# A list of non-root users that are permitted to use the CNI configurations
+# specified in the 'allow net networks' directive, and can join existing
+# network namespaces listed in the 'allow netns paths' directive.
+# By default only root may use CNI configurations, or join existing network
+# namespaces, except in the case of a fakeroot execution where only the 
+# 40_fakeroot.conflist CNI configuration is used. The restriction only applies
+# when Apptainer is running in SUID mode and the user is non-root.
 #allow net users = gmk, apptainer
 {{ range $index, $owner := .AllowNetUsers }}
 {{- if eq $index 0 }}allow net users = {{ else }}, {{ end }}{{$owner}}
@@ -449,11 +470,13 @@ allow container dir = {{ if eq .AllowContainerDir true }}yes{{ else }}no{{ end }
 
 # ALLOW NET GROUPS: [STRING]
 # DEFAULT: NULL
-# Allow specified root administered CNI network configurations to be used by the
-# specified list of users. By default only root may use CNI configuration,
-# except in the case of a fakeroot execution where only 40_fakeroot.conflist
-# is used. This feature only applies when Apptainer is running in
-# SUID mode and the user is non-root.
+# A list of non-root groups that are permitted to use the CNI configurations
+# specified in the 'allow net networks' directive, and can join existing
+# network namespaces listed in the 'allow netns paths' directive.
+# By default only root may use CNI configurations, or join existing network
+# namespaces, except in the case of a fakeroot execution where only the 
+# 40_fakeroot.conflist CNI configuration is used. The restriction only applies
+# when Apptainer is running in SUID mode and the user is non-root.
 #allow net groups = group1, apptainer
 {{ range $index, $group := .AllowNetGroups }}
 {{- if eq $index 0 }}allow net groups = {{ else }}, {{ end }}{{$group}}
@@ -462,13 +485,23 @@ allow container dir = {{ if eq .AllowContainerDir true }}yes{{ else }}no{{ end }
 # ALLOW NET NETWORKS: [STRING]
 # DEFAULT: NULL
 # Specify the names of CNI network configurations that may be used by users and
-# groups listed in the allow net users / allow net groups directives. Thus feature
+# groups listed in the allow net users / allow net groups directives. This restriction
 # only applies when Apptainer is running in SUID mode and the user is non-root.
 #allow net networks = bridge
 {{ range $index, $group := .AllowNetNetworks }}
 {{- if eq $index 0 }}allow net networks = {{ else }}, {{ end }}{{$group}}
 {{- end }}
 
+# ALLOW NETNS PATHS: [STRING]
+# DEFAULT: NULL
+# Specify the paths to network namespaces that may be joined by users and groups
+# listed in the allow net users / allow net groups directives. This restriction
+# only applies when Apptainer is running in SUID mode and the user is non-root.
+#allow netns paths = /var/run/netns/my_network
+{{ range $index, $path := .AllowNetnsPaths }}
+{{- if eq $index 0 }}allow netns paths = {{ else }}, {{ end }}{{$path}}
+{{- end }}
+
 # ALWAYS USE NV ${TYPE}: [BOOL]
 # DEFAULT: no
 # This feature allows an administrator to determine that every action command
